# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *

def host_as_nvidia_gpu():
    wmi = wmi_info(keys=['Win32_VideoController'])
    gpu = wmi['Win32_VideoController']

    if isinstance(gpu, dict):
        if 'NVIDIA' in gpu['Name']:
            return True

    if isinstance(gpu, list):
        for v in gpu:
            if 'NVIDIA' in v['Name']:
                return True
            
    return False

def install():
    # Declaring local variables
    bin_name = glob.glob("*.exe")[0]
    driver_path = makepath(systemdrive, 'NVIDIA')

    if not host_as_nvidia_gpu():
        error("The current computer doesn't have a nvidia GPU !")

    print("Extracting: " + bin_name)
    unzip_with_7zip(bin_name, driver_path)
    remove_file(bin_name)

    # Installing the software
    print("Installing: %s" % bin_name)

    install_exe_if_needed(
        makepath(driver_path, "setup.exe"),
        silentflags="-s -clean -noreboot -noeula",
        key="{B2FE1952-0186-46C3-BAEC-A80AA35AC5B8}_Display.Driver",
        min_version=control.get_software_version(),
        timeout=900,
    )

    print("Deletion of the driver folder")
    remove_tree(driver_path)

    del uninstallkey[:] # Clear uninstallkey list

def uninstall():
    print(f'Uninstallation of {control.asrequirement()}')

    nvidia_display_nvx_files = glob.glob('C:\\Program Files\\NVIDIA Corporation\\Installer2\\**\\DisplayDriver.NVX')
    for nvx_f in nvidia_display_nvx_files:
        with open(nvx_f) as f:
            data = f.read()
        data = data.replace('uninstallReboot="true"', 'uninstallReboot="false"')
        with open(nvx_f, 'w') as f:
            f.write(data)
    
    driversToUninstall = ["Display.Driver","HDAudio.Driver"]
    for driver in driversToUninstall:
        run(f"C:\\Windows\\SysWOW64\\RunDll32.EXE 'C:\\Program Files\\NVIDIA Corporation\\Installer2\\InstallerCore\\NVI2.DLL',UninstallPackage {driver} -silent")